bayespy.inference.vmp.nodes.categorical.CategoricalDistribution
===============================================================

.. currentmodule:: bayespy.inference.vmp.nodes.categorical

.. autoclass:: CategoricalDistribution

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~CategoricalDistribution.__init__
      ~CategoricalDistribution.compute_cgf_from_parents
      ~CategoricalDistribution.compute_fixed_moments_and_f
      ~CategoricalDistribution.compute_logpdf
      ~CategoricalDistribution.compute_mask_to_parent
      ~CategoricalDistribution.compute_message_to_parent
      ~CategoricalDistribution.compute_moments_and_cgf
      ~CategoricalDistribution.compute_phi_from_parents
      ~CategoricalDistribution.plates_from_parent
      ~CategoricalDistribution.plates_to_parent
      ~CategoricalDistribution.random
   
   

   
   
   